=====
gazta
=====


You are two steps away from winning a handmade cheese!
======================================================


Install this package and see what happens.

Just for EuroPython 2016 attendants


CodeSyntax, 2016
